/**
 * EasyBeans
 * Copyright (C) 2007-2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EasyBeansHTTPTransportFactory.java 2546 2008-02-29 13:49:31Z sauthieg $
 * --------------------------------------------------------------------------
 */
package org.ow2.easybeans.cxf.http;

import java.io.IOException;

import org.apache.cxf.Bus;
import org.apache.cxf.service.model.EndpointInfo;
import org.apache.cxf.transport.Destination;
import org.apache.cxf.transport.DestinationFactory;
import org.apache.cxf.transport.http.AbstractHTTPTransportFactory;

/**
 * Easybeans specialized HTTP TransportFactory. This class is a Singleton and
 * can be accessed directly from the {@link EasyBeansCXFServlet}.
 * @author Guillaume Sauthier
 * @author Florent Benoit
 */
public final class EasyBeansHTTPTransportFactory extends AbstractHTTPTransportFactory
                                                 implements DestinationFactory {

    /**
     * Build a new EasyBeans transport factory for the given bus.
     * @param bus the CXF bus.
     */
    public EasyBeansHTTPTransportFactory(final Bus bus) {
        setBus(bus);
    }

    /**
     * @return a new EasyBeans destination for the given EndPoint Info.
     * @param endpointInfo the given endpoint information
     * @throws IOException if the EasyBeans destination is not created.
     */
    public Destination getDestination(final EndpointInfo endpointInfo) throws IOException {
        // Remove the URL start (keep only the last part)
        String path = ServletHelper.getTrimmedPath(endpointInfo.getAddress());

        // Go in the cache ?
        EasyBeansDestination d = URLMapper.getInstance().get(path);
        if (d == null) {
            // not in the cache, build a new instance
            d = new EasyBeansDestination(getBus(), this, endpointInfo);
        }
        return d;
    }

}
